User Documentation
==================

.. toctree::
   :maxdepth: 1

   tutorial
   plans
   documents
   metadata
   callbacks
   state-machine
   simulation
   progress-bar
   event_descriptors
   async
   multi_run_plans
   debugging
   run_engine_api
   utils
   magics
   otel-tracing
   from-pyepics-to-bluesky
   comparison-with-spec
   hardware-interfaces
   tiled-writer
   appendix